==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/doc/DocFormFile.md <==
select
===
select @pageTag(){
				t.FORM_FILE_ID,
		t.DISPLAY_NO,
		if(ifnull(t.FILE_NAME,v.ORIGINAL_NAME)='',v.ORIGINAL_NAME,t.FILE_NAME) FILE_NAME,
		t.FILE_NO,
		t.FILE_TYPE_ID,
		t.FILE_VERSION_ID,
		t.FORM_ID,
		t.IS_USE,
		t.MEMO,
		t.PRIMARY_KEY,
		t.PROJECT_ID,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.BILL_NO,
		t.BILL_MONEY,
		t.BILL_Date,
		t.BILL_TAX_MONEY,
		t.WORKITEMID,
		t.BILL_TYPE,
		GETDICNAME('INVOICE_TYPEA_ALL',t.BILL_TYPE) BILL_TYPE_TEXT,
		t.BILL_CODE,
		t.BILL_TAX_ADD,
		t.BILL_CATEGORY,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.BILL_REMARK,
		t.SALE_NAME,
		t.BILL_TAX_RATE,
		t.SERVICE_TYPE,
		f.form_code
	 @}
from DOC_FORM_FILE t
left join doc_file_version v on v.VERSION_ID = t.FILE_VERSION_ID
left join gen_form f on f.id = t.form_id
@if(!isEmpty(fileNature)){
,bas_dic d
@}
where t.is_use = 'Y'
@if(!isEmpty(fileNature)){
	@if(fileNature=='2'){
		and d.dic_value = t.BILL_TYPE and d.dic_code = 'INVOICE_TYPE'
	@}else if(fileNature=='3'){
		and d.dic_value = t.BILL_TYPE and d.dic_code = 'ticketType'
	@}
@}
and  t.BILL_TYPE is not null
and (t.CREATE_ACCOUNT = #loginuser.accountid# or v.CREATE_ACCOUNT = #loginuser.accountid#)
@if(!isEmpty(applyPerson)){
    and getaccountname(t.CREATE_ACCOUNT)  like #applyPerson# ESCAPE '/'  
@}
@if(!isEmpty(invoceType)){
    and t.BILL_TYPE= #invoceType#
@}

@if(!isEmpty(reimbursed)&&reimbursed=='N'){
    and ifnull(t.PRIMARY_KEY,'') =''
@}else if(!isEmpty(reimbursed)&&reimbursed=='Y'){
    and ifnull(t.PRIMARY_KEY,'') !=''
@}
@if(!isEmpty(startDate) && !isEmpty(endDate)){
and t.BILL_date
 between #startDate# and #endDate#
@}
@if(!isEmpty(search)){
and(
 upper(t.FILE_NAME) like #search#  ESCAPE '/'  or 
 upper(t.BILL_NO) like #search#  ESCAPE '/'  or 
 upper(t.BILL_MONEY) like #search#  ESCAPE '/'  or 
 upper(t.BILL_TAX_MONEY) like #search#  ESCAPE '/'  or 
 upper(t.BILL_CODE) like #search#  ESCAPE '/'  or 
 upper(t.BILL_TAX_ADD) like #search#  ESCAPE '/'  or 
 upper(t.BILL_REMARK) like #search#  ESCAPE '/'  or 
 upper(t.SALE_NAME) like #search#  ESCAPE '/'  or 
 upper(t.SERVICE_TYPE) like #search#  ESCAPE '/' 
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.FORM_FILE_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

==> fine-web-0.0.2-20220909.090829-172.jar: beetlsql/doc/DocFormFile.md <==
select
===
select @pageTag(){
				t.FORM_FILE_ID,
		t.DISPLAY_NO,
		if(ifnull(t.FILE_NAME,v.ORIGINAL_NAME)='',v.ORIGINAL_NAME,t.FILE_NAME) FILE_NAME,
		t.FILE_NO,
		t.FILE_TYPE_ID,
		t.FILE_VERSION_ID,
		t.FORM_ID,
		t.IS_USE,
		t.MEMO,
		t.PRIMARY_KEY,
		t.PROJECT_ID,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.BILL_NO,
		t.BILL_MONEY,
		t.BILL_Date,
		t.BILL_TAX_MONEY,
		t.WORKITEMID,
		t.BILL_TYPE,
		GETDICNAME('INVOICE_TYPEA_ALL',t.BILL_TYPE) BILL_TYPE_TEXT,
		t.BILL_CODE,
		t.BILL_TAX_ADD,
		t.BILL_CATEGORY,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.BILL_REMARK,
		t.SALE_NAME,
		t.BILL_TAX_RATE,
		t.SERVICE_TYPE,
		f.form_code
	 @}
from DOC_FORM_FILE t
left join doc_file_version v on v.VERSION_ID = t.FILE_VERSION_ID
left join gen_form f on f.id = t.form_id
@if(!isEmpty(fileNature)){
,bas_dic d
@}
where t.is_use = 'Y'
@if(!isEmpty(fileNature)){
	@if(fileNature=='2'){
		and d.dic_value = t.BILL_TYPE and d.dic_code = 'INVOICE_TYPE'
	@}else if(fileNature=='3'){
		and d.dic_value = t.BILL_TYPE and d.dic_code = 'ticketType'
	@}
@}
and  t.BILL_TYPE is not null
and (t.CREATE_ACCOUNT = #loginuser.accountid# or v.CREATE_ACCOUNT = #loginuser.accountid#)
@if(!isEmpty(applyPerson)){
    and getaccountname(t.CREATE_ACCOUNT)  like #applyPerson# ESCAPE '/'  
@}
@if(!isEmpty(invoceType)){
    and t.BILL_TYPE= #invoceType#
@}

@if(!isEmpty(reimbursed)&&reimbursed=='N'){
    and ifnull(t.PRIMARY_KEY,'') =''
@}else if(!isEmpty(reimbursed)&&reimbursed=='Y'){
    and ifnull(t.PRIMARY_KEY,'') !=''
@}
@if(!isEmpty(startDate) && !isEmpty(endDate)){
and t.BILL_date
 between #startDate# and #endDate#
@}
@if(!isEmpty(search)){
and(
 upper(t.FILE_NAME) like #search#  ESCAPE '/'  or 
 upper(t.BILL_NO) like #search#  ESCAPE '/'  or 
 upper(t.BILL_MONEY) like #search#  ESCAPE '/'  or 
 upper(t.BILL_TAX_MONEY) like #search#  ESCAPE '/'  or 
 upper(t.BILL_CODE) like #search#  ESCAPE '/'  or 
 upper(t.BILL_TAX_ADD) like #search#  ESCAPE '/'  or 
 upper(t.BILL_REMARK) like #search#  ESCAPE '/'  or 
 upper(t.SALE_NAME) like #search#  ESCAPE '/'  or 
 upper(t.SERVICE_TYPE) like #search#  ESCAPE '/' 
)@}
@if(!isEmpty(flowsql)){
#text(flowsql)#
@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.FORM_FILE_ID desc
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

findFileByInviceInfo
===
select count(1)
from doc_form_file t
where t.BILL_NO=#billNo# and T.BILL_CODE=#billCode#
and t.is_use='Y'
@if(!isEmpty(id)){
	and t.FORM_FILE_ID!=#id#
@}
